EmailRequestModel

Struct EmailRequestModel 

pub struct EmailRequestModel {
    pub master_password_hash: Option<String>,
    pub otp: Option<String>,
    pub auth_request_access_code: Option<String>,
    pub secret: Option<String>,
    pub new_email: String,
    pub new_master_password_hash: Option<String>,
    pub token: String,
    pub key: Option<String>,
}
EmailRequestModel : This model is used in the second step of self service email change after the master password hash has been verified. The token is used to verify ownership of the new email.

Fields

master_password_hash: Option<String>otp: Option<String>auth_request_access_code: Option<String>secret: Option<String>new_email: Stringnew_master_password_hash: Option<String>token: Stringkey: Option<String>

Implementations

Source

impl EmailRequestModel

pub fn new(new_email: String, token: String) -> EmailRequestModel

This model is used in the second step of self service email change after the master password hash has been verified. The token is used to verify ownership of the new email.